@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2023 2022-2023 Abilian SAS <https://abilian.com/>
+#
+# SPDX-License-Identifier: MIT
+
 import os
 import sys
 from pathlib import Path
@@ -34,6 +38,16 @@ def check(args: list[str]):
     run("deptry .")
 
 
+@app.command("security-check")
+def security_check():
+    """Run security checks."""
+    run("pip-audit")
+    run("safety check")
+
+    # TODO: don't assume source dir is src
+    # run("bandit -r src")
+
+
 @app.command()
 def test():
     """Run tests."""
